.. SPDX-FileCopyrightText: 2024 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: WTFPL
.. No warranty.

gentle.pms
==========

.. automodule:: gentle.pms
   :members:

.. autosummary::
   :toctree: pms

   gentle.pms.portagepm
